@@ -10,7 +10,8 @@ def exceptions_endpoint(atomic: bool=True):
         def inner(request, *args, **kwargs):
             try:
                 if atomic:
-                    return transaction.atomic(endpoint(request, *args, **kwargs))
+                    with transaction.atomic():
+                        return endpoint(request, *args, **kwargs)
                 return endpoint(request, *args, **kwargs)
             except Exception as e:
                     return get_response(str(e), status.HTTP_400_BAD_REQUEST)
